from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers
import json


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL = 'http://duma.gov.ru/data.json'
URL_COMMITTEE = 'http://duma.gov.ru/duma/commissions/'
HOST = 'http://duma.gov.ru'


def parser():
    people = []
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL)
    if html.status_code == 200:
        try:
            res = json.loads(html.text)
            res = res['persons']
            for person in res:
                flag = False
                try:
                    image = HOST + person['photo']
                except:
                    image = '-'
                url = HOST + person['url']
                if url.find('persons') != -1:
                    if url.find('staff') != -1:
                        flag = True
                    log.debug(f"Parsing {url}")
                    try:
                        person_html = f.get_html(url)
                        soup = BeautifulSoup(person_html.text, 'html.parser')
                        soup = soup.find('div', class_='content--s').get_text().lower()
                        soup = f.get_dig_date(soup[soup.find('рождения: ')+len('рождения: '):soup.find('года')])
                    except:
                        soup = f.get_dig_date('01 01 1901')
                    if soup == -1:
                        soup = f.get_dig_date('01 01 1901')
                    work = None
                    for pos in person['commission_positions']:
                        if pos['position_text'].find('член') != -1 and work != 19:
                            work = 20
                        else:
                            work = 19
                    if work == None:
                        flag = True
                    if not flag:
                        people.append(
                            {
                                'image_link': image,
                                'first_name': person['first_name'],
                                'middle_name': person['second_name'],
                                'last_name': person['last_name'],
                                'link': url,
                                'bday': soup['day'],
                                'bmonth': soup['month'],
                                'byear': soup['year'],
                                'position_id': work
                            }
                        )
            log.debug("The script stops working")
            return people
        except:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]


if __name__ == '__main__':
    print(parser())


from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)

URL = 'http://www.scrf.gov.ru/about/leadership/'
HOST = 'http://www.scrf.gov.ru'


def get_person(link):
    html_link = f.get_html(link)
    soup = BeautifulSoup(html_link.text, 'html.parser')
    item = soup.find('div', class_='profile')
    try:
        image_link = HOST + item.find('div', class_='profile-pic__img').find('img').get('src')
    except:
        image_link = '-'
    item = item.find('figcaption', class_='profile-pic__caption')
    name = item.find('dt').get_text()
    work = item.find('dd').get_text()
    work = f.get_work(work, 29)
    name = f.split_name(name, 2)
    try:
        item = soup.find('div', class_='l-col1').get_text()
        item = item[item.find('Родился') + len('Родился') + 1:item.find('.')-2]
        item = item.replace(chr(10), ' ')
        date = f.get_dig_date(item)
    except:
        date = {'day': 1, 'month': 1, 'year': 1901}
    return {'position_id': work, 'first_name': name[1], 'middle_name': name[2], 'last_name': name[0],
            'bday': date['day'], 'bmonth': date['month'], 'byear': date['year'], 'image_link': image_link, 'link': link}


def get_people(html):
    soup = BeautifulSoup(html, 'html.parser')
    links = []
    people = []
    try:
        items = soup.find_all('a', class_='person')
        for item in items:
            if not item.find('dd').get_text().find('помощник') != -1:
                links.append(HOST + item.get('href'))
        for link in links:
            people.append(get_person(link))
        return people
    except:
        return 1


def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        people = get_people(html.text)
        if people == 1:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]



import os
from parser_libraries import functions as f
from bs4 import BeautifulSoup
import logging
import logging.handlers
import urllib3

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)

URL = 'http://audit.gov.ru/structure/'
HOST = 'http://audit.gov.ru'


def get_person(link):
    try:
        html = f.get_html(link['link'])
        soup = BeautifulSoup(html.text, 'html.parser')
        image_link = soup.find('div', class_='photo').find('img').get('src')
        cont = soup.find('div', class_='info').get_text().split(maxsplit=3)
        name = []
        for i in range(0, 3):
            name.append(cont[i].lower())
        bday = soup.find('div', class_='expand-field').get_text().lower()
        ind = bday.find('родил')
        bday = f.get_dig_date(bday[ind:bday.find('год')].split(maxsplit=1)[1])
        return {'position_id': link['work'], 'first_name': name[1], 'middle_name': name[2], 'last_name': name[0],
                'bday': bday['day'], 'bmonth': bday['month'], 'byear': bday['year'], 'image_link': image_link, 'link': link['link']}
    except:
        return 1

def parser():
    log.debug(f"The script {__name__} starts working")
    links = []
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, 'html.parser')
        items = soup.find_all('div', class_='structure-row flex')
        items.append(soup.find('div', class_='structure-row flex structure-row--apparat-first'))
        for item in items:
            arr = item.find_all('a')
            for ar in arr:
                work = ar.get_text()
                work = work.split(maxsplit=3)
                work = f.get_work(work[-1].lower(), 34)
                if work != -1:
                    links.append({'link': HOST + ar.get('href'), 'work': work})
        for link in links:
            box = get_person(link)
            if box == 1:
                return [{'code': 1, 'script': os.path.basename(__file__)}]
            people.append(box)
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]

if __name__ == '__main__':
    print(parser())


from parser_libraries import functions as f
from bs4 import BeautifulSoup
from parser_libraries import SQL
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)



URL = 'https://www.mid.ru/activity/shots/personnel/extraordinary_ambassador#main-content'


def parser():
    log.debug(f"The script {__name__} starts working")
    info = SQL.get_con_info()
    html = f.get_selenium_html(URL, chromium=info['chromium_path'], driver=info['chromedriver_path'], params=info['use_chromium'])
    info = None
    soup = BeautifulSoup(html, 'html.parser')
    contents = soup.find('section', class_='block')
    contents = contents.find_all('tr')
    contents = contents[1:]
    people = []
    for content in contents:
        name = content.get_text().lower().replace('\n', ' ')
        while name.find('  ') != -1:
            name = name.replace('  ', ' ')
        work = name.find('ПОСТОЯННЫЙ ПРЕДСТАВИТЕЛЬ РОССИЙСКОЙ ФЕДЕРАЦИИ'.lower())
        if work == -1:
            work = 10
        else:
            work = 11
        try:
            date = name[name.find('.')-2:name.find('.')+8].replace('.', ' ')
            date = f.get_dig_date(date)
        except:
            date = f.get_dig_date('01 01 1901')
        if date == -1:
            date = f.get_dig_date('01 01 1901')
        name = name[1:name.find('.')-2]
        name = f.get_name(name)
        people.append({
            'image_link': '-',
            'first_name': name[1],
            'middle_name': name[2],
            'last_name': name[0],
            'link': URL,
            'bday': date['day'],
            'bmonth': date['month'],
            'byear': date['year'],
            'position_id': work
        })
    log.debug("The script stops working")
    return people

if __name__ == "__main__":
    SQL.mySQL_save(parser())


import time
import os
from bs4 import BeautifulSoup
from parser_libraries import functions as f
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL = 'http://government.ru/gov/persons/'
HOST = 'http://government.ru'


def get_person(URL):
    try:
        people = []
        html = f.get_html(URL + 'bio')
        link = URL + 'bio'
        flag = False
        if html.status_code == 404:
            html = f.get_html(URL)
            link = URL
            flag = True
        soup = BeautifulSoup(html.text, 'html.parser')
        text = soup.find('div', class_='page_wrapper bio')
        if not text:
            flag = True
        name = f.get_name(soup.find('p', class_='vcard_name').get_text().lower())
        work = soup.find('p', class_='vcard_position').get_text().lower()
        image_link = soup.find('div', class_='vcard_photo').find('img').get('srcset')
        image_link = image_link[:-3]
        if not flag:
            text = text.find('p', class_='')
            text = text.find('p').get_text().lower()
            indl = text.find(' ')
            text = text[indl+1:text.find(' г')]
            date = f.get_dig_date(text)
            if date == -1:
                linking = 'https://ru.wikipedia.org/wiki/'
                nam = name[2][0].upper()+name[2][1:]+',_'+name[0][0].upper()+name[0][1:]+'_'+name[1][0].upper()+name[1][1:]
                for na in nam:
                    if na != '_' and na != ',':
                        strlist = f.get_base(ord(na), 2)
                        str1 = '110'+strlist[:5]
                        str2 = '10'+strlist[5:]
                        str1 = '%' + str(f.get_base(f.get_dec(int(str1),2),16)).upper()
                        str2 = '%' + str(f.get_base(f.get_dec(int(str2),2),16)).upper()
                        linking += str1+str2
                    else:
                        linking += na
                html2 = f.get_html(linking)
                try:
                    date_soup = BeautifulSoup(html2.text, 'html.parser')
                    date_soup = date_soup.find('span', class_='bday').get_text()
                    date = f.get_dig_date(date_soup, 2)
                except: date = {"year": 1901, "day": 1, "month": 1}
        else:
            linking = 'https://ru.wikipedia.org/wiki/'
            nam = name[2][0].upper()+name[2][1:]+',_'+name[0][0].upper()+name[0][1:]+'_'+name[1][0].upper()+name[1][1:]
            for na in nam:
                if na != '_' and na != ',':
                    strlist = f.get_base(ord(na), 2)
                    str1 = '110'+strlist[:5]
                    str2 = '10'+strlist[5:]
                    str1 = '%' + str(f.get_base(f.get_dec(int(str1),2),16)).upper()
                    str2 = '%' + str(f.get_base(f.get_dec(int(str2),2),16)).upper()
                    linking += str1+str2
                else:
                    linking += na
            html2 = f.get_html(linking)
            try:
                date_soup = BeautifulSoup(html2.text, 'html.parser')
                date_soup = date_soup.find('span', class_='bday').get_text()
                date = f.get_dig_date(date_soup, 2)
            except:
                date = {"year": 1901, "day": 1, "month": 1}
        work = f.get_work(work, 2)
        try:
            a = work[1]
            people.append({
                    'image_link': image_link,
                    'first_name': name[0],
                    'middle_name': name[1],
                    'last_name': name[2],
                    'link': link,
                    'bday': date['day'],
                    'bmonth': date['month'],
                    'byear': date['year'],
                    'position_id': a
                 }
            )
            people.append({
                'image_link': image_link,
                'first_name': name[0],
                'middle_name': name[1],
                'last_name': name[2],
                'link': link,
                'bday': date['day'],
                'bmonth': date['month'],
                'byear': date['year'],
                'position_id': work[0]
            }
            )
        except:
            people.append({
                'image_link': image_link,
                'first_name': name[0],
                'middle_name': name[1],
                'last_name': name[2],
                'link': link,
                'bday': date['day'],
                'bmonth': date['month'],
                'byear': date['year'],
                'position_id': work
                }
            )
        return people
    except:
        return 1


def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        time.sleep(5)
        soup = BeautifulSoup(html.text, 'html.parser')
        list = soup.find_all('li', class_='person')
        for pos in list:
            box = get_person(HOST + pos.find('a', class_='person_slide').get('href'))
            if box == 1:
                return [{'code': 1, 'script': os.path.basename(__file__)}]
            people.extend(box)
            time.sleep(0.1)
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]


if __name__ == "__main__":
    print(parser())


from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import time
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL = 'http://council.gov.ru/structure/committees/'


def get_people(html):
    people = []
    links = []
    try:
        soup = BeautifulSoup(html, 'html.parser')
        soup = soup.find('div', class_='wrapper')
        links.append({'link': soup.find('div', class_='senator__person senator__person_medium').find('a').get('href'), 'work': 14})
        firsts = soup.find_all('div', class_='first_deputy_chairman')
        for first in firsts:
            links.append({'link': first.find('a').get('href'), 'work': 14})
        seconds = soup.find_all('div', class_='deputy_chairmen')
        for second in seconds:
            links.append({'link': second.find('a').get('href'), 'work': 14})
        lasts = soup.find_all('div', class_='deputy_members col_4 col')
        lasts.extend(soup.find_all('div', class_='deputy_members col_4 col col_last'))
        for last in lasts:
            links.append({'link': last.find('a').get('href'), 'work': 15})
        i = 1
        for link in links:
            log.debug(str(i) + '/' + str(len(links)))
            link_html = f.get_html(link['link'])
            link_soup = BeautifulSoup(link_html.text, 'html.parser')
            name = f.get_name(link_soup.find('h2', class_='senators_title').get_text().lower())
            try:
                image_link = link_soup.find('img', class_='person_img').get('srcset')
                image_link = image_link[:image_link.find(' 2x')]
            except:
                image_link = "-"
            date = link_soup.find('p').get_text()
            date = f.get_dig_date(date[date.find(': ')+2:date.find(' года')])
            people.append({
                'image_link': image_link,
                'first_name': name[1],
                'middle_name': name[2],
                'last_name': name[0],
                'link': link['link'],
                'bday': date['day'],
                'bmonth': date['month'],
                'byear': date['year'],
                'position_id': link['work']
            })
            time.sleep(0.5)
            i += 1
        log.debug("The script stops working")
        return people
    except:
        return 1


def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, 'html.parser')
        items = soup.find_all('div', class_='block__department')
        i = 1
        for item in items:
            log.debug('Page ' + str(i) + '/' + str(len(items)))
            link = item.find('a').get('href')
            link_html = f.get_html(link)
            box = get_people(link_html.text)
            if box == 1:
                return ({'code': 1, 'script': os.path.basename(__file__)})
            people.extend(box)
            i += 1
        return people
    else:
        return ({'code': 2, 'script': os.path.basename(__file__)})

if __name__ == '__main__':
    print(parser())


from parser_libraries import functions as f
import os
from bs4 import BeautifulSoup
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL = 'http://duma.gov.ru/duma/structure/'
HOST = 'http://duma.gov.ru'


def get_links(html):
    soup = BeautifulSoup(html, 'html.parser')
    items = soup.find_all('section', class_='section section--embedded mobile-no-padding')
    links = []
    people = []
    for item in items:
        info = item.find_all('a', class_='object object--fractions link link--color')
        if info:
            for inf in info:
                chairman = f.get_html(HOST + inf.get('href') + 'chairman')
                soup_for_chairman = BeautifulSoup(chairman.text, 'html.parser')
                lk = soup_for_chairman.find('div', class_='person__content person__content--right')
                links.append(HOST + lk.find('a').get('href'))
        else:
            data = item.find_all('div', class_='person person--s')
            for dat in data:
                links.append(HOST + dat.find('a').get('href'))
    return links


def get_person(html):
    try:
        link = f.get_html(html)
        soup = BeautifulSoup(link.text, 'html.parser')
        postfix = '--mobile'
        if not soup.find('div', class_=('person person'+postfix)):
            postfix = '--l'
        item = soup.find('div', class_=('person person'+postfix))
        image = item.find('picture')
        image = item.find('img')
        image_link = HOST + image.get('src')
        item = item.find('div', class_='person__content person__content'+postfix)
        name = item.find('h2', class_='person__title person__title'+postfix).get_text()
        name = f.split_name(name)
        if postfix == '--l':
            work = item.find('p', class_='person__position person__position' + postfix).get_text()
        else:
            work = item.find('div', class_='person__position person__position--wide')
            work = work.find('div')
            work = work.find('a').get_text()
        work = f.get_work(work, mode=16)
        date = soup.find('div', class_='content--s')
        date = date.find('div', class_='text').get_text()
        date = date[date.find(': ')+1:date.find('года')]
        date = f.get_dig_date(date)
        return {'position_id': work, 'first_name': name[1], 'middle_name': name[2], 'last_name': name[0], 'bday': date['day'], 'bmonth': date['month'], 'byear': date['year'], 'image_link': image_link, 'link': html}
    except:
        return 1



def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        links = get_links(html.text)
        for link in links:
            box = get_person(link)
            if box == 1:
                return [{'code': 1, 'script': os.path.basename(__file__)}]
            people.append(box)
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]


from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import time
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL_COMMITTEE = 'http://www.gosduma.net/structure/committees/'
HOST = 'http://www.gosduma.net'

def get_links(html):
    links = []
    soup = BeautifulSoup(html, 'html.parser')
    items = soup.find_all('div', class_='section-line')
    for item in items:
        item = item.find('div', class_='table-data td-filter')
        links.extend(item.find_all('tr'))
    links_real = []
    for link in links:
        if link.find('td'):
            link = link.find('td')
            links_real.append(HOST + link.find('a').get('href'))
    return links_real


def get_data(html, name):
    soup = BeautifulSoup(html, 'html.parser')
    item = []
    if soup.find('p', class_='deputat-info-date'):
        item.append(soup.find('p', class_='deputat-info-date').get_text().replace('Дата рождения: ', ''))
    else:
        item.append('-')
    soup = soup.find('div', class_='deputat-info-left')
    if soup.find('img'):
        item.append(HOST + soup.find('img').get('src'))
    else:
        linking = 'https://ru.wikipedia.org/wiki/'
        name = f.get_name(name)
        nam = name[0][0].upper() + name[0][1:] + ',_' + name[1][0].upper() + name[1][1:] + '_' + name[2][0].upper() + name[2][1:]
        for na in nam:
            if na != '_' and na != ',':
                strlist = f.get_base(ord(na), 2)
                str1 = '110' + strlist[:5]
                str2 = '10' + strlist[5:]
                str1 = '%' + str(f.get_base(f.get_dec(int(str1), 2), 16)).upper()
                str2 = '%' + str(f.get_base(f.get_dec(int(str2), 2), 16)).upper()
                linking += str1 + str2
            else:
                linking += na
        image_html = f.get_html(linking)
        soup_3 = BeautifulSoup(image_html.text, 'html.parser')
        soup_3 = soup_3.find('table', class_='infobox')
        link = soup_3.find('img')
        link = link.get('srcset')
        link = link[link.rfind('//'):link.find(' 2x')]
        item.append(link)
    return item


def get_people(html):
    soup = BeautifulSoup(html, 'html.parser')
    if soup.find('div', class_='table-data td-filter'):
        items = soup.find('div', class_='table-data td-filter')
        items = items.find_all('tr')
        count = 1
        flag = True
        people = []
        for item in items:
            log.debug(str(count) + '/' + str(len(items)))
            if item.find('td'):
                data = []
                work = item.find_all('td')
                work = work[-1]
                work = work.get_text().lower()
                link = HOST + item.find('a').get('href')
                name = item.find('a').get('title').lower()
                data = get_data(f.get_html(link).text, name)
                data[0] = data[0].replace('года', '')
                name = f.get_name(name)
                list_data = f.get_dig_date(data[0])
                people.append({
                    'image_link': data[1],
                    'first_name': name[1],
                    'middle_name': name[2],
                    'last_name': name[0],
                    'link': link,
                    'bday': list_data['day'],
                    'bmonth': list_data['month'],
                    'byear': list_data['year'],
                    'position_id': f.get_work(work, 19)
                })
            count = count + 1
    else:
        people = -1
    return people


def parser():
    log.debug(f"The script {__name__} starts working")
    html_links = f.get_html(URL_COMMITTEE)
    if html_links.status_code == 200:
        links = get_links(html_links.text)
        people = []
        for j in range(0, len(links)+1):
            try:
                log.debug('Page ' + str(j) + '/' + str(len(links)))
                html_committee = f.get_html(links[j])
                people_list = get_people(html_committee.text)
                if people_list != -1:
                    people.extend(people_list)
            except:
                j -= 1
            time.sleep(1)
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]



import os
from parser_libraries import functions as f
from bs4 import BeautifulSoup
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)

URL = 'http://www.cikrf.ru/about/'
HOST = 'http://www.cikrf.ru'


def get_person(html):
    try:
        link_html = f.get_html(html['link'])
        soup = BeautifulSoup(link_html.text, 'html.parser')
        name = f.get_name(soup.find('span', class_='name').get_text().lower())
        image_link = HOST + soup.find('div', class_='col-xs-12 col-sm-4 col-md-3 img').find('img').get('src')
        date = soup.find('p').get_text()
        date = f.get_dig_date(date[date.find(' ')+1:date.find(' года')])
        return {
            'image_link': image_link,
            'first_name': name[1],
            'middle_name': name[2],
            'last_name': name[0],
            'link': html['link'],
            'bday': date['day'],
            'bmonth': date['month'],
            'byear': date['year'],
            'position_id': html['work']
        }
    except:
        return 1


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL)
    links = []
    people = []
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, 'html.parser')
        items = soup.find('div', class_='content_body')
        items = items.find('div', class_='row')
        items = items.find_all('div', class_='election_committee_item col-xs-6 col-md-4')
        for item in items:
            text = item.find('script')
            if text != None:
                text.get_text()
                if text.find('none'):
                    continue
            else:
                links.append({'link': HOST + item.find('a').get('href'), 'work': f.get_work(item.find('span', class_='position').get_text(), mode=38)})
        for link in links:
            box = get_person(link)
            if box == 1:
                return [{'code': 1, 'script': os.path.basename(__file__)}]
            people.append(box)
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]



from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL_1 = "http://supcourt.ru/about/structure/220/"
URL_2 = "http://supcourt.ru/about/structure/221/"
URL_3 = "http://supcourt.ru/about/structure/222/"
URL_4 = "http://supcourt.ru/about/structure/223/"
HOST = "http://supcourt.ru"


def get_links(url):
    links = []
    people = []
    html = f.get_html(url)
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, "html.parser")
        soup = soup.find('div', class_='vs-structure')
        soup = soup.find_all('div', class_='clearfix')
        for sou in soup:
            try:
                links.append(HOST + sou.find('a').get('href'))
            except:
                sou = sou.find('div', class_='vs-text').find('h2').get_text().lower()
                name = f.get_name(sou)
                people.append(
                    {
                        'image_link': "-",
                        'first_name': name[1],
                        'middle_name': name[2],
                        'last_name': name[0],
                        'link': url,
                        'bday': 1,
                        'bmonth': 1,
                        'byear': 1901,
                        'position_id': 26
                    }
                )
        for link in links:
            person = get_person(link)
            if person != 1:
                people.append(person)
            else:
                return 1
        return people
    else:
        return 1


def get_person(link):
    html = f.get_html(link)
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, 'html.parser')
        soup = soup.find_all('div', class_='vs-inner clearfix')
        soup = soup[-2]
        name = f.get_name(soup.find('div', class_='vs-grid-medium').get_text().replace('\n', '').lower())
        try:
            image_link = HOST + soup.find('img').get('src')
        except:
            image_link = "-"
        try:
            date = soup.get_text().lower()
            if date.find('родился') != -1:
                if date.find('год') != -1:
                    date = f.get_dig_date(date[date.find('родился')+len('родился'): date.find('год')])
                else:
                    date = f.get_dig_date(date[date.find('родился') + len('родился'): date.find('г.')])
            elif date.find('родилась') != -1:
                if date.find('год') != -1:
                    date = f.get_dig_date(date[date.find('родилась')+len('родилась'): date.find('год')])
                else:
                    date = f.get_dig_date(date[date.find('родилась') + len('родилась'): date.find('г.')])
        except:
            date = f.get_dig_date("01 01 1901")
        if date == -1:
            date = f.get_dig_date("01 01 1901")
        if type(date) != type({}):
            date = f.get_dig_date("01 01 1901")
        return {
            'image_link': image_link,
            'first_name': name[1],
            'middle_name': name[2],
            'last_name': name[0],
            'link': link,
            'bday': date['day'],
            'bmonth': date['month'],
            'byear': date['year'],
            'position_id': 26
        }
    else:
        return 1


def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    ar = get_links(URL_1)
    if ar != 1:
        people.extend(ar)
    else:
        return [{'code': 1, 'script': os.path.basename(__file__)}]

    ar = get_links(URL_2)
    if ar != 1:
        people.extend(ar)

    else:
        return [{'code': 1, 'script': os.path.basename(__file__)}]

    ar = get_links(URL_3)
    if ar != 1:
        people.extend(ar)
    else:
        return [{'code': 1, 'script': os.path.basename(__file__)}]

    html = f.get_html(URL_4)
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, 'html.parser')
        links = soup.find_all('h1', class_='vs-structure-list-section')
        for link in links:
            link = link.find('a').get('href')
            ar = get_links(HOST+link)
            if ar != 1:
                people.extend(ar)
            else:
                return [{'code': 1, 'script': os.path.basename(__file__)}]
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]
    log.debug("The script stops working")
    return people


from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)

URL = 'https://pravo.ru/arbitr_practice/courts/119/'


def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        try:
            soup = BeautifulSoup(html.text, 'html.parser')
            items = soup.find('table', class_='no_stripes no_padding common_info')
            items = items.find_all('tr')
            for item in items:
                work = f.get_work(item.find('td', class_='muted').get_text().lower(), mode=24)
                name = f.get_name(item.find('a').get_text().lower())
                link = item.find('a').get('href')
                link_html = f.get_html(link)
                link_soup = BeautifulSoup(link_html.text, 'html.parser')
                link_soup = link_soup.find('div', class_='card')
                image_link = link_soup.find('img').get('src')
                text = link_soup.find('p').get_text()
                ind = text.find(' года')
                if ind == -1:
                    ind = text.find('г.')
                text = text[text.find(' ')+1:ind]
                date = f.get_dig_date(text)
                if date == -1:
                    text = text[text.find(":")+1:]
                    date = f.get_dig_date(text)
                people.append({
                    'image_link': image_link,
                    'first_name': name[1],
                    'middle_name': name[2],
                    'last_name': name[0],
                    'link': link,
                    'bday': date['day'],
                    'bmonth': date['month'],
                    'byear': date['year'],
                    'position_id': work
                })
            log.debug("The script stops working")
            return people
        except:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]

if __name__ == "__main__":
    print(parser())


from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers
import urllib3

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

host = 'http://www.arbitr.ru'
url = host+'/as/'
addition = 'about/ourJudges/'
addition_kr = 'kasyanova'


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


def parser_person(link, wbsite):
    try:
        html = f.get_html(link["link"])
        soup = BeautifulSoup(html.text, 'html.parser')
        soup = soup.find('div', class_='b-content-body js-content-body')
        try:
            image_link = wbsite[:-1] + soup.find('img').get('src')
        except:
            image_link = '-'
        name = soup.find('div', class_='b-card-title-container')
        work = name.find('h3', class_='b-card-title b-card-post').get_text().lower()
        name = name.find('h2').get_text().replace('.', ' ')
        if name == "" or name == None:
            name = link["name"].replace(".", " ")
        name = f.get_name(name)
        date = soup.find_all('dl', class_='b-card-info-block g-clrfix')
        try:
            date = date[-1].get_text().lower()
            if date.find('родился') != -1:
                year = date.find('года')
                if year != -1:
                    date = date[date.find('родился')+len('родился'):year]
                elif date.find('г.') != -1:
                    date = date[date.find('родился')+len('родился'):date.find('г.')]
            elif date.find('родилась') != -1:
                year = date.find('года')
                if year != -1:
                    date = date[date.find('родилась') + len('родилась'):year]
                elif date.find('г.') != -1:
                    date = date[date.find('родилась') + len('родилась'):date.find('г.')]
            else:
                date = date[date.find('.')-2:date.find('.')+8]
            date = date.replace('.', ' ')
            date = f.get_dig_date(date)
        except:
            date = -1
        lst = {}
        if date == -1 or date['year'] > 2000:
            lst = {
            'image_link': image_link,
            'first_name': name[1],
            'middle_name': name[2],
            'last_name': name[0],
            'link': link["link"],
            'bday': 1,
            'bmonth': 1,
            'byear': 1901,
            'position_id': f.get_work(work, 42),
            }
        else:
            lst = {
            'image_link': image_link,
            'first_name': name[1],
            'middle_name': name[2],
            'last_name': name[0],
            'link': link["link"],
            'bday': date['day'],
            'bmonth': date['month'],
            'byear': date['year'],
            'position_id': f.get_work(work, 42),
            }
        return lst
    except:
        return 1


def parser_people_links(link):
    links = []
    if link.find('krasnoyarsk') != -1:
        html = f.get_html(link+addition+addition_kr)
    else:
        html = f.get_html(link+addition)
    if html.status_code == 503:
        log.warning("Server offline, skipping")
        return None
    soup = BeautifulSoup(html.text, 'html.parser')
    soup = soup.find('div', class_='l-columns')
    if soup != None:
        soup = soup.find('div', class_='l-column l-column--left js-column')
        try:
            soup1 = soup.find('ul', class_='b-menu js-menu menu')
            soup4 = soup1.find('li', class_='b-menu-item--active')
            try:
                soup4 = soup4.find('div', class_='b-submenu js-submenu b-submenu--all')
                soup1 = soup4
            except:
                soup1 = soup1.find("div", class_="b-menu-item js-menu-item b-menu-item--active js-menu-item--active b-menu-item--is_submenu")
                soup1 = soup1.find('div', class_='b-submenu js-submenu b-submenu--all')
            soup1 = soup1.find('ul', class_='b-menu js-menu menu')
            soup1 = soup1.find_all('li')
        except:
            try:
                soup3 = soup.find_all('ul', class_='b-menu js-menu menu accordion')
                soup3 = soup3[3]
                soup1 = soup3.find_all('li')
            except:
                try:
                    soup2 = soup.find('ul', class_='b-menu js-menu menu accordion')
                    soup2 = soup2.find('li', class_='b-menu-item js-menu-item b-menu-item--active js-menu-item--active b-menu-item--is_submenu')
                    soup2 = soup2.find('div', class_='b-submenu js-submenu b-submenu--accordion')
                    soup2 = soup2.find('ul', class_='b-menu js-menu menu accordion')
                    soup1 = soup2.find_all('li')
                except:
                    soup3 = soup.find('ul', class_='b-menu js-menu menu ')
                    soup3 = soup3.find('li', class_= 'b-menu-item js-menu-item b-menu-item--active js-menu-item--active b-menu-item--is_submenu first')
                    soup3 = soup3.find('div', class_='b-submenu js-submenu b-submenu--all')
                    soup3 = soup3.find('ul', class_='b-menu js-menu menu ')
                    soup1 = soup3.find_all('li')
        for sou in soup1:
            sou = sou.find('a', class_='item_link')
            if sou != None:
                if sou.get('href').find(".ru") == -1:
                    links.append({"link":link[:-1] + sou.get('href'), "name": sou.get_text()})
                else:
                    if sou.get('href').find("http") == -1:
                        links.append({"link": "http:/" + sou.get('href'), "name": sou.get_text()})
                    else:
                        links.append({"link": sou.get('href'), "name": sou.get_text()})
    else:
        links = None
    return links


def parser_direct_link(link):
    html = f.get_html(link)
    soup = BeautifulSoup(html.text, 'html.parser')
    soup = soup.find_all('table', cellpadding='5')
    try:
        soup = soup[-1]
    except:
        pass
    soup = soup.find_all('a')
    soup = soup[-1].get('href')
    return soup


def parser_website(link):
    links = []
    html = f.get_html(link)
    soup = BeautifulSoup(html.text, 'html.parser')
    soup = soup.find_all('a', class_='zag21')
    for sou in soup:
        links.append(host + sou.get('href'))
    return links


def get_orenburg():
    links = []
    people = []
    log.debug(f'Parsing https://orenburg.arbitr.ru/')
    html = f.get_html('https://orenburg.arbitr.ru/about/ourJudges/aleksandrov')
    soup = BeautifulSoup(html.text, 'html.parser')
    soup = soup.find('div', class_='l-columns')
    soup = soup.find('div', class_='l-column l-column--left js-column')
    soup = soup.find('ul', class_='b-menu js-menu menu')
    soup = soup.find('div', class_='b-submenu js-submenu b-submenu--all')
    soup = soup.find('ul', class_='b-menu js-menu menu')
    soup = soup.find_all('li')
    for sou in soup:
        sou = sou.find('a', class_='item_link')
        if sou != None:
            links.append({"link":'https://orenburg.arbitr.ru' + sou.get('href'), "name": sou.get_text()})
    for link in links:
        people.append(parser_person(link, 'https://orenburg.arbitr.ru/'))
    return people

def parser_irk(link):
    people = []
    html_irk_1 = f.get_html(link)
    soup_irk_1 = BeautifulSoup(html_irk_1.text, "html.parser")
    soup_irk_1 = soup_irk_1.find("div", class_="single")
    soup_irk_1 = soup_irk_1.find_all("a")
    for syd in soup_irk_1:
        html_syd = f.get_html(syd.get("href"))
        soup_irk_syd = BeautifulSoup(html_syd.text, "html.parser")
        soup_irk_syd = soup_irk_syd.find("div", class_="single")
        soup_irk_syd = soup_irk_syd.find_all("a")
        for sou in soup_irk_syd:
            name = sou.get_text()
            name = name.split()
            work = 44
            if len(name) > 3:
                work = 42
                name = name[4:]
            people.append({
                'image_link': "-",
                'first_name': name[1],
                'middle_name': name[2],
                'last_name': name[0],
                'link': sou.get("href"),
                'bday': 1,
                'bmonth': 1,
                'byear': 1901,
                'position_id': work,
            })
    return people

def parser():
    log.debug(f"The script {__name__} starts working")
    links = []
    people = []

    html = f.get_html(url)
    if html.status_code == 200:
        soup = BeautifulSoup(html.text, 'html.parser')
        soup = soup.find_all(class_='menu2')
        for sou in soup:
            links.append(host+sou.get('href'))
        for link in links:
            website_links = parser_website(link)
            for website_link in website_links:
                direct_link = parser_direct_link(website_link)+'/'
                log.debug(f'Parsing {direct_link}')
                i = 0
                while i<3:
                    try:
                        people_links = parser_people_links(direct_link)
                        i=4
                    except:
                        if i == 2:
                            if direct_link.find('perm') != -1 :
                                pass
                            elif direct_link.find('orenburg') != -1:
                                pass
                            else:
                                return [{'code': 1, 'script': os.path.basename(__file__)}]

                        people_links = None
                        i+=1
                        log.warning(f'Duplicate or non-templated html at -> {direct_link}')
                if people_links != None:
                    for person_link in people_links:
                        if person_link != None:
                            person = parser_person(person_link, direct_link)
                            if person != 1:
                                people.append(person)
                            else:
                                return [{'code': 1, 'script': os.path.basename(__file__)}]
        log.debug('Parsing https://ipc.arbitr.ru/')
        people_links = parser_people_links('https://ipc.arbitr.ru/')
        for person_link in people_links:
            if person_link != None:
                person = parser_person(person_link, 'https://ipc.arbitr.ru/')
                if person != 1:
                    people.append(person)
        people.extend(get_orenburg())


        html_tver = f.get_html("https://tver.arbitr.ru/node/3515")
        soup_tver = BeautifulSoup(html_tver.text, "html.parser")
        soup_tver = soup_tver.find("div", class_="node")
        tver_list = soup_tver.find_all("p")
        tver_list = tver_list[1:]
        for item in tver_list:
            try:
                name = item.find("strong").get_text().replace("\n", "")
                name = f.get_name(name)
                people.append({
                    'image_link': "-",
                    'first_name': name[1],
                    'middle_name': name[2],
                    'last_name': name[0],
                    'link': "https://tver.arbitr.ru/node/3515",
                    'bday': 1,
                    'bmonth': 1,
                    'byear': 1901,
                    'position_id': 44,
                })
            except:
                pass

        html_fasvso = f.get_html("http://fasvso.arbitr.ru/about/struktura_suda/svedeniya_o_sud_yah/")
        soup_fasvso = BeautifulSoup(html_fasvso.text, "html.parser")
        soup_fasvso = soup_fasvso.find('div', class_="evaldyarticles")
        soup_fasvso = soup_fasvso.find_all("div")
        for item in soup_fasvso:
            li = "http://fasvso.arbitr.ru" + item.find("a").get("href")
            name = item.get_text().lower().replace("\n", "")
            name = f.get_name(name)
            people.append({
                'image_link': "-",
                'first_name': name[1],
                'middle_name': name[2],
                'last_name': name[0],
                'link': li,
                'bday': 1,
                'bmonth': 1,
                'byear': 1901,
                'position_id': 44,
            })

        html_irk = f.get_html(
            "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/predsedatel-arbitrazhnogo-suda-irkutskoj-oblasti/")
        soup_irk = BeautifulSoup(html_irk.text, "html.parser")
        soup_irk = soup_irk.find("div", class_="single")
        im = soup_irk.find("strong")
        name = im.get_text()
        name = f.get_name(name)
        soup_irk = soup_irk.find_all("p")
        date = soup_irk[2].get_text().lower()
        if date.find('родился') != -1:
            year = date.find('года')
            if year != -1:
                date = date[date.find('родился') + len('родился'):year]
            elif date.find('г.') != -1:
                date = date[date.find('родился') + len('родился'):date.find('г.')]
        elif date.find('родилась') != -1:
            year = date.find('года')
            if year != -1:
                date = date[date.find('родилась') + len('родилась'):year]
            elif date.find('г.') != -1:
                date = date[date.find('родилась') + len('родилась'):date.find('г.')]
        else:
            date = date[date.find('.') - 2:date.find('.') + 8]
        date = date.replace('.', ' ')
        date = f.get_dig_date(date)

        people.append({
            'image_link': im.find("a").get("href"),
            'first_name': name[0],
            'middle_name': name[1],
            'last_name': name[2],
            'link': "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/predsedatel-arbitrazhnogo-suda-irkutskoj-oblasti",
            'bday': date["day"],
            'bmonth': date["month"],
            'byear': date["year"],
            'position_id': 42,
        })

        people.extend(parser_irk(
            "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/sudebnaya-kollegiya-po-rassmotreniyu-sporov-voznikayushhih-iz-administrativnyh-i-inyh-publichnyh-pravootnoshenij/"))
        people.extend(parser_irk(
            "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/sudebnaya-kollegiya-po-rassmotreniyu-sporov-voznikayushhih-iz-grazhdanskih-i-inyh-pravootnoshenij/"))

        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]

if __name__ == '__main__':
    print(parser())


from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)

URL = 'https://sledcom.ru/sk_russia/leaders'
HOST = 'https://sledcom.ru'


def get_person(html):
    try:
        soup = BeautifulSoup(html, 'html.parser')
        item = soup.find('div', class_='inner-page__list-item')
        name = f.get_name(item.find('a').get_text().lower())
        link = HOST + item.find('a').get('href')
        link_html = f.get_html(link)
        soup_link = BeautifulSoup(link_html.text, 'html.parser')
        item = soup_link.find('article', class_='direction-view')
        image_link = HOST + item.find('img').get('src')
        date = item.find('section', class_='collapsible__item')
        date = date.find('div', class_='collapsible__body').get_text()
        date = f.get_dig_date(date[date.find('родился ')+len('родился '): date.find('.')-2])
        return {'position_id': 28, 'first_name': name[1], 'middle_name': name[2], 'last_name': name[0],
                'bday': date['day'], 'bmonth': date['month'], 'byear': date['year'], 'image_link': image_link, 'link': link}
    except:
        return 1


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL)
    person = []
    if html.status_code == 200:
        box = get_person(html.text)
        if box == 1:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
        person.append(box)
        log.debug("The script stops working")
        return person
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]



import os
from parser_libraries import functions as f
from bs4 import BeautifulSoup
from bs4.dammit import EncodingDetector
import logging
import logging.handlers

# Президиум ВАС РФ

logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL = "http://arbitr.ru/struct/judges/presidium/"
HOST = "http://arbitr.ru"


def get_person(a_row):
    link = HOST + a_row.get('href')
    name = a_row.get_text().split()
    html = f.get_html(link)
    http_enc = html.encoding if 'charset' in html.headers.get('content-type', '').lower() else None
    html_enc = EncodingDetector.find_declared_encoding(html.content, is_html=True)
    enc = html_enc or http_enc
    soup = BeautifulSoup(html.content, 'html.parser', from_encoding=enc)

    try:
        name_pos_block = soup.find('h3').find_next_sibling('div').find('p').find_parent()
        pos_block = name_pos_block.find('p').find_next('em')

        for e in pos_block.find_all('br'):
            e.extract()

        pos = pos_block.get_text().replace('\r\n', ' ').replace('\n', '').lower()

        try:
            image_link = HOST + name_pos_block.find_all('img')[0].get('src')
        except:
            image_link = HOST + name_pos_block.find_parent().find_all('img')[0].get('src')
        try:
            bday_block = name_pos_block.find_all('p')[2]
        except:
            bday_block = name_pos_block.find_parent('td').find_all('p')[1]
        bday = bday_block.get_text()
        bday = f.get_dig_date(bday[bday.find(' ')+1 : bday.find(' года')])
        if bday == -1:
            try:
                bday_block = name_pos_block.find_all('p')[1]
                bday = bday_block.get_text()
                bday = f.get_dig_date(bday[bday.find(' ') + 1: bday.find(' года')])
            except:
                bday_block = name_pos_block.find_parent().find_all('p')[2]
                bday = bday_block.get_text()
                bday = f.get_dig_date(bday[bday.find(' ') + 1: bday.find(' года')])

        if pos.find('заместитель') != -1 or pos.find('судья') != -1 or pos.find('состава') != -1:
            pos = 47
        else:
            pos = 46

        return {
            'image_link': image_link,
            'first_name': name[1],
            'middle_name': name[2],
            'last_name': name[0],
            'link': link,
            'bday': bday['day'],
            'bmonth': bday['month'],
            'byear': bday['year'],
            'position_id': pos
        }
    except:
        return None


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL)
    if html.status_code == 200:
        http_enc = html.encoding if 'charset' in html.headers.get('content-type', '').lower() else None
        html_enc = EncodingDetector.find_declared_encoding(html.content, is_html=True)
        enc = html_enc or http_enc
        soup = BeautifulSoup(html.content, 'html.parser', from_encoding=enc)
        table = soup.find('blockquote')
        rows = table.find_all('a')
        people = []
        for row in rows:
            person = get_person(row)
            people.append(person)
        if people == 1:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]

if __name__ == '__main__':
    print(parser())


import os
from parser_libraries import functions as f
from bs4 import BeautifulSoup
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL_1 = "http://www.cdep.ru/index.php?id=32"
URL_2 = "http://viperson.ru/search?query="
HOST = "http://viperson.ru"


def get_person(html):
    soup = BeautifulSoup(html, 'html.parser')
    name = soup.find('div', class_="contentBody customArea").find_next('span').get_text().lower()
    name = f.get_name(name)
    return name


def get_content(URL, name):
    search = f.get_html(URL)
    if search.status_code == 200:
        soup = BeautifulSoup(search.text, 'html.parser')
        href = soup.find('table', class_='pi-sup__table').find_next('td', class_='pi-sup__img-td').find_next('a', class_='pi-sup__img-box').get('href')
        link = HOST + href
        html = f.get_html(link)
        if html.status_code == 200:
            soup = BeautifulSoup(html.text, 'html.parser')
            image_link = HOST + soup.find('div', class_='wrap').find_next('div', class_='prsn__box group').find_next('img', class_='prsn__img').get('src')
            position_id = 45
            b_date = soup.find('div', class_='wrap').find_next('div', class_='prsn__box group').find_next('div', class_='prsn__descr').find_next('div', class_='prsn__live').text
            b_date = f.get_dig_date(b_date.replace('года', ''))
            person = {
                'image_link': image_link,
                'first_name': name[0],
                'middle_name': name[1],
                'last_name': name[2],
                'link': link,
                'bday': b_date['day'],
                'bmonth': b_date['month'],
                'byear': b_date['year'],
                'position_id': position_id
            }
            return person
        else:
            return [{'code': 2, 'script': os.path.basename(__file__)}]
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL_1)
    people = []
    if html.status_code == 200:
        name = get_person(html.text)
        URL = URL_2
        for i in range(len(name)):
            URL += name[i] + "+"
        URL = URL[:-1]
        person = get_content(URL, name)
        people.append(person)
        if people == 1:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]


import os
from parser_libraries import functions as f
from bs4 import BeautifulSoup
import logging
import logging.handlers
import urllib3

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


HOST = 'https://ru.wikipedia.org'


def get_content(html, cont_id, cont_work_id):
    try:
        soup = BeautifulSoup(html.text, 'html.parser')
        table = soup.find('table', class_='infobox')
        if cont_id == 1:
            work = table.find('th').get_text().lower()
            work = f.get_work(work)
            image_box = table.find_all('td', class_='infobox-image')
            image_box = image_box[-1]
            p_link = HOST + image_box.find('span', class_='no-wikidata').find('a').get('href')
        else:
            lists = table.find_all('tr')
            content = lists[cont_id-1]
            work = cont_work_id
            p_link = HOST + content.find('td').find('a').get('href')
        p_soup = BeautifulSoup(f.get_html(p_link).text, 'html.parser')
        image_link = p_soup.find('table', class_='infobox').find('img').get('srcset')
        image_link = image_link[image_link.rfind('//'):image_link.find(' 2x')]
        person = {
            'name': p_soup.find('th', class_='infobox-above').get_text().lower(),
            'p_link': p_link,
            'b_date': f.get_dig_date(p_soup.find('span', class_='bday').get_text(), 2),
            #'ef_date': table.find('span', class_='no-wikidata').find_next('a').find_next('a').get_text() + " " + table.find('span', class_='no-wikidata').find_next('a').find_next('a').find_next('a').get_text(),
            'image_link': 'https:' + image_link,
            'work': work
        }
        return person
    except:
        return 1


def parser(URL, cont_id=1, cont_id_work=37):
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL)
    if html.status_code == 200:
        person = get_content(html, cont_id, cont_id_work)
        if person == 1:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
        content = []
        content.append({
            'first_name': person['name'].split()[0],
            'middle_name': person['name'].split()[1],
            'last_name': person['name'].split()[2],
            'link': person['p_link'],
            'bday': person['b_date']['day'],
            'bmonth': person['b_date']['month'],
            'byear': person['b_date']['year'],
            #'ef_date': get_dig_date(person['ef_date'].replace('года', '')),
            'image_link': person['image_link'],
            'position_id': person['work']
        })
        log.debug("The script stops working")
        return content
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]



import os
from bs4 import BeautifulSoup
from parser_libraries import functions as f
import logging
import logging.handlers

logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL = "https://ru.m.wikipedia.org/wiki/%D0%9F%D0%BE%D0%BB%D0%BD%D0%BE%D0%BC%D0%BE%D1%87%D0%BD%D1%8B%D0%B9_%D0%BF%D1%80%D0%B5%D0%B4%D1%81%D1%82%D0%B0%D0%B2%D0%B8%D1%82%D0%B5%D0%BB%D1%8C_%D0%BF%D1%80%D0%B5%D0%B7%D0%B8%D0%B4%D0%B5%D0%BD%D1%82%D0%B0_%D0%A0%D0%BE%D1%81%D1%81%D0%B8%D0%B9%D1%81%D0%BA%D0%BE%D0%B9_%D0%A4%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D1%86%D0%B8%D0%B8_%D0%B2_%D1%84%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D0%BB%D1%8C%D0%BD%D0%BE%D0%BC_%D0%BE%D0%BA%D1%80%D1%83%D0%B3%D0%B5#:~:text=%D0%9F%D0%BE%D0%BB%D0%BD%D0%BE%D0%BC%D0%BE%D1%87%D0%BD%D1%8B%D0%B9%20%D0%BF%D1%80%D0%B5%D0%B4%D1%81%D1%82%D0%B0%D0%B2%D0%B8%D1%82%D0%B5%D0%BB%D1%8C%20%D0%BF%D1%80%D0%B5%D0%B7%D0%B8%D0%B4%D0%B5%D0%BD%D1%82%D0%B0%20%D0%A0%D0%BE%D1%81%D1%81%D0%B8%D0%B9%D1%81%D0%BA%D0%BE%D0%B9%20%D0%A4%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D1%86%D0%B8%D0%B8%20%D0%B2%20%D1%84%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D0%BB%D1%8C%D0%BD%D0%BE%D0%BC%20%D0%BE%D0%BA%D1%80%D1%83%D0%B3%D0%B5%20%E2%80%94%20%D0%B4%D0%BE%D0%BB%D0%B6%D0%BD%D0%BE%D1%81%D1%82%D0%BD%D0%BE%D0%B5%20%D0%BB%D0%B8%D1%86%D0%BE,%D0%B3%D0%BB%D0%B0%D0%B2%D1%8B%20%D0%B3%D0%BE%D1%81%D1%83%D0%B4%D0%B0%D1%80%D1%81%D1%82%D0%B2%D0%B0%20%D0%BD%D0%B0%20%D1%82%D0%B5%D1%80%D1%80%D0%B8%D1%82%D0%BE%D1%80%D0%B8%D0%B8%20%D0%BE%D0%BA%D1%80%D1%83%D0%B3%D0%B0"
HOST = "https://ru.m.wikipedia.org"

def parser():
    log.debug(f"The script {__name__} starts working")
    people = []
    html = f.get_html(URL)
    if html.status_code == 200:
        try:
            soup = BeautifulSoup(html.text, 'html.parser')
            soup = soup.find('div', class_='content')
            soup = soup.find_all('section')
            soup = soup[3:-4]
            links = []
            for sou in soup:
                sou = sou.find('ul')
                sou = sou.find_all('li')
                sou = sou[-1]
                try:
                    link = sou.find('a').get('href')
                    links.append(HOST + link)
                except:
                    name = f.get_name(sou.find('a').get_text().lower().replace(',', ''))
                    person = {'image_link': "-",
                        'first_name': name[1],
                        'middle_name': name[2],
                        'last_name': name[0],
                        'link': URL,
                        'bday': 1,
                        'bmonth': 1,
                        'byear': 1901,
                        'position_id': 7}
                    people.append(
                        person
                    )
                if links[-1].find("edit") != -1:
                    name = f.get_name(sou.find('a').get_text().lower().replace(',', ''))
                    person = {'image_link': "-",
                              'first_name': name[1],
                              'middle_name': name[2],
                              'last_name': name[0],
                              'link': URL,
                              'bday': 1,
                              'bmonth': 1,
                              'byear': 1901,
                              'position_id': 7}
                    people.append(
                        person
                    )
                    links.pop()
            for link in links:
                html_cont = f.get_html(link)
                soup = BeautifulSoup(html_cont.text, 'html.parser')
                soup = soup.find('table', class_='infobox')
                name = soup.find('th', class_='infobox-above').get_text().lower().split()
                try:
                    image = "https:" + soup.find('td', class_='infobox-image').find('img').get('src')
                except:
                    image = '-'
                try:
                    date = f.get_dig_date(soup.find('span', class_='bday').get_text(), 2)
                except:
                    date = f.get_dig_date('01 01 1901')
                work = soup.find_all('tr')[3].get_text().lower()
                if work.find('заместитель председателя правительства') != -1:
                    work = 4
                else:
                    work = 7
                person1 = {
                    'image_link': image,
                    'first_name': name[0],
                    'middle_name': name[1],
                    'last_name': name[2],
                    'link': link,
                    'bday': date['day'],
                    'bmonth': date['month'],
                    'byear': date['year'],
                    'position_id': work
                }
                people.append(
                    person1
                )
            log.debug(f"The script stops working")
            return people
        except:
            print(people)
            return [{'code': 1, 'script': os.path.basename(__file__)}]
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]

if __name__ == "__main__":
    print(parser())



from parser_libraries import functions as f
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)

URL= 'http://council.gov.ru/structure/administration/'
HOST = 'http://council.gov.ru'


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL)
    if html.status_code == 200:
        try:
            soup = BeautifulSoup(html.text, 'html.parser')
            contents = soup.find_all('div', class_='senator__person senator__person_medium')
            people = []
            for content in contents:
                link = content.find('a').get('href')
                if link.find('http'):
                    link = HOST + link
                image_link = content.find('img').get('srcset')
                image_link = image_link[0:-3]
                name = f.get_name(content.find('img').get('alt').lower())
                work = content.find('a', class_='senators_title').get('title').lower()
                if work.find('заместител') != -1:
                    work = 13
                else:
                    work = 12
                date = content.find('div', class_='person_info_private tooltip__wrapper').get_text().lower()
                date = date[date.find(': ')+2:date.find('года')]
                date = f.get_dig_date(date)
                people.append({
                    'image_link': image_link,
                    'first_name': name[1],
                    'middle_name': name[2],
                    'last_name': name[0],
                    'link': link,
                    'bday': date['day'],
                    'bmonth': date['month'],
                    'byear': date['year'],
                    'position_id': work
                })
            log.debug("The script stops working")
            return people
        except:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]



from parser_libraries import functions as f
from bs4 import BeautifulSoup
import time
import os
import logging
import logging.handlers


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


URL_JUDGE = 'http://www.ksrf.ru/ru/Info/Judges/Pages/default.aspx'
HOST = 'http://www.ksrf.ru/ru/Info/Judges/Pages/'


def get_people(html):
    people = []
    soup = BeautifulSoup(html, 'html.parser')
    items = soup.find_all('ul', class_='dfwp-column dfwp-list')
    for item in items:
        item = item.find('ul', class_='dfwp-list')
        cases = item.find_all('li', class_='dfwp-item')
        for case in cases:
            case = case.find('a')
            if case.get('title') != '':
                case = case.get('href').replace('\t', '')
                case = get_link(case)
            else:
                case = ''
            if case != '':
                box = get_person(HOST+case)
                if box == 1:
                    return 1
                people.append(box)
    return people


def get_person(link):
    try:
        if link != '':
            html = f.get_html(link)
            soup = BeautifulSoup(html.text, 'html.parser')
            item = soup.find('table', class_='s4-wpTopTable')
            image_link = item.find('img').get('src')
            item = item.find('tr').find('table').find_all('tr')
            name = item[0].get_text().lower().strip(' ')
            name = f.get_name(name)
            work = item[1].get_text().lower()
            text = item[2].get_text()
            ind = text.find(' ')+1
            ind_2 = text.find('года')-1
            ind_3 = text.find('г.')-1
            if ind_2 == -2:
                ind_2 = ind_3
            text = text[ind:ind_2]
            text = f.get_dig_date(text)
            person = {
                'position_id': f.get_work(work, 21),
                'first_name': name[1],
                'middle_name': name[2],
                'last_name': name[0],
                'bday': text['day'],
                'bmonth': text['month'],
                'byear': text['year'],
                'image_link': image_link,
                'link': link,
            }
        return person
    except:
        return 1

def get_link(str):
    ind = str.find('j')
    str = str[ind:]
    return str


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(URL_JUDGE)
    if html.status_code == 200:
        people = get_people(html.text)
        if people == 1:
            return [{'code': 1, 'script': os.path.basename(__file__)}]
        time.sleep(5)
        log.debug("The script stops working")
        return people
    else:
        return [{'code': 2, 'script': os.path.basename(__file__)}]


from setuptools import setup

setup(
    name='parser_module',
    version='4.16',
    packages=['parser_module'],
    author_email='ivan.frinom@gmail.com',
    install_requires=[
        'parser_libraries>=3.4'
    ]
)



from parser_libraries import functions as f
from parser_libraries import SQL as SQL
from bs4 import BeautifulSoup
import os
import logging
import logging.handlers


COMPLEX_URL = 'https://ru.wikipedia.org/wiki/%D0%A1%D1%83%D0%B1%D1%8A%D0%B5%D0%BA%D1%82%D1%8B_%D0%A0%D0%BE%D1%81%D1%81%D0%B8%D0%B9%D1%81%D0%BA%D0%BE%D0%B9_%D0%A4%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D1%86%D0%B8%D0%B8'
HOST = 'https://ru.wikipedia.org/'


logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG)


def get_yandex_image(name):
    info = SQL.get_con_info()
    link = 'https://yandex.ru/images/search?text=' + name[0] + '%20' + name[1] + '%20' + name[2]
    html = f.get_selenium_html(link, chromium=info['chromium_path'], driver=info['chromedriver_path'], params=info['use_chromium'])
    soup = BeautifulSoup(html, 'html.parser')
    soup = soup.find('a', class_='serp-item__link')
    soup = soup.find('img').get('src')
    return soup


def get_wiki_person(link, work_id):
    html = f.get_html(link)
    soup = BeautifulSoup(html.text, 'html.parser')
    full_name = soup.find('h1', class_='firstHeading').get_text().lower().replace(',', '')
    if full_name.find('(') != -1:
        full_name = full_name[:full_name.find('(')]
    full_name = f.get_name(full_name)
    soup = soup.find('table', class_='infobox')
    try:
        image_link = soup.find('td', class_='infobox-image').find('img').get('srcset')
        if image_link != None:
            image_link = 'https:' + image_link[image_link.rfind(', ')+2:image_link.find(' 2x')]
        else:
            image_link = 'https:' + soup.find('td', class_='infobox-image').find('img').get('src')
    except:
        image_link = 'https:/' + get_yandex_image(full_name)
        image_link = image_link.replace(' ', '')
        image_link = image_link.replace('///', '//')
    soup = soup.find('span', class_='bday').get_text()
    if soup != None:
        date = f.get_dig_date(soup, 2)
    else:
        date = f.get_dig_date('01 01 1901')
    return {'position_id': work_id, 'first_name': full_name[1], 'middle_name': full_name[2], 'last_name': full_name[0],
            'bday': date['day'], 'bmonth': date['month'], 'byear': date['year'], 'image_link': image_link, 'link': link}


def get_page(link):
    people = []
    html = f.get_html(link)
    soup = BeautifulSoup(html.text, 'html.parser')
    soup = soup.find('table', class_='infobox')
    soup = soup.find_all('tr')
    for a in soup:
        try:
            cont = a.find('th', class_='plainlist').get_text().lower()
            if cont != None:
                if cont.find('губернатор') != -1 or cont.find('председатель') != -1 or cont.find('мэр') != -1  or cont.find('премьер-министр') != -1 or cont.find('глава') != -1:
                    name = a.find('td').get_text()
                    if name.find('[') != -1:
                        name = name[:name.find('[')]
                    elif name.find('(') != -1:
                        name = name[:name.find('(')]
                    title = a.find('td').find('a').get('title')
                    if title.find('страница отсутствует') == -1:
                        person_link = a.find('td').find('a').get('href')
                        people.append(get_wiki_person(HOST + person_link, 33))
                    else:
                        title = title.replace(' (страница отсутствует)', '')
                        if title.find('(') != -1:
                            title = title[:title.find('(')]
                        if title.rfind(' ') == len(title) - 1:
                            title = title[:-1]
                        full_name = [title[:title.find(',')].lower(), title[title.find(',')+1:title.rfind(' ')].lower(), title[title.rfind(' ')+1:].lower()]
                        for part in full_name:
                            part = part.replace(' ', '')
                        image_link = 'https:' + get_yandex_image(full_name)
                        image_link = image_link.replace(' ', '')
                        image_link = image_link.replace('///', '//')
                        people.append({
                                       'position_id': 33,
                                       'first_name': full_name[1],
                                       'middle_name': full_name[2],
                                       'last_name': full_name[0],
                                       'bday': 1,
                                       'bmonth': 1,
                                       'byear': 1901,
                                       'image_link': image_link,
                                       'link': link
                                       }
                                      )
        except:
            continue
    return people


def parser():
    log.debug(f"The script {__name__} starts working")
    html = f.get_html(COMPLEX_URL)
    soup = BeautifulSoup(html.text, 'html.parser')
    links = []
    people = []
    soup = soup.find('table', class_='standard')
    prob = soup.find_all('tr', class_='dark')
    soup = soup.find_all('tr')
    soup = soup[2:-1]
    for a in soup:
        flag = True
        for b in prob:
            if a == b:
                flag = False
        if flag:
            links.append(HOST + a.find('a').get('href'))
    i = 1
    for link in links:
        log.debug(f'{i}/{len(links)+1}')
        i += 1
        a = get_page(link)
        people.extend(a)
    log.debug("The script stops working")
    return people
